#!/usr/bin/python3
import os
import re

from colorama import Fore
from colorama import init
from .utils import PatternLocations
from .utils import renameFile

init(autoreset=True)

class TrimFilename:

    def __init__(self, pattern_position, pattern):
        self.pattern_position = pattern_position
        self.pattern = pattern
        self.renamed_files_list = {}

    def add_to_renamed_list(self, old_name, new_name, dir_path):
        old_path = os.path.join(dir_path, old_name)

        self.renamed_files_list[old_path]=new_name

    def removeDefaultPattern(self, name, dirPath):
        ''' storing name in a list for manipulations on characters individually
        '''
        nameList = list(name)

        #To not rename files starting with only '.'
        if nameList[0] != '.':
            for char in name:
                #remove all non alphabet characters from filename
                if not(char.isalpha() or char == '.'):
                    del(nameList[nameList.index(char)])
                else:
                    break

            new_name = ''.join(nameList)

            if renameFile(name, new_name, dirPath):
                self.add_to_renamed_list(name, new_name, dirPath)

    def removePatternAtBeg(self, name, dirPath, patternToBeRemoved):
        ''' Removes the pattern matched at beginning of the filename
        '''
        new_name = re.sub( '^' +  patternToBeRemoved, '', name)
        if renameFile(name, new_name, dirPath):
            self.add_to_renamed_list(name, new_name, dirPath)

    def removePatternInString(self, name, dirPath, patternToBeRemoved):
        ''' Checks for pattern in whole string and removes it if match is found
        '''
        new_name = re.sub( patternToBeRemoved, '', name )
        if renameFile(name, new_name, dirPath):
            self.add_to_renamed_list(name, new_name, dirPath)

    def removePatternAtEnd(self, name, dirPath, patternToBeRemoved):
        ''' Matches pattern at end of the name
        '''
        new_name = re.sub( patternToBeRemoved + '$', '', name )
        if new_name != name:
            proceedWithRemoval = input("Do you really want to change "
                   "extension from " + name + " to " + new_name + "(y/n) : ")
            #TODO: not prompt for each file
            if(proceedWithRemoval == 'y'):
                if renameFile(name, new_name, dirPath):
                    self.add_to_renamed_list(name, new_name, dirPath)

    def parseDir(self, path):
        ''' Parse the path given for all files and folders contained recursively
        '''
        print('Entered parseDirfname'+path)

        #renamedList contains the list of files renamed
        if os.path.exists(path):
            for dirPath, dirs, files in os.walk(path):

                for name in files:
                    if self.pattern_position == PatternLocations.patternInString:
                        self.removePatternInString(name, dirPath, self.pattern)

                    elif self.pattern_position == PatternLocations.patternAtBeg:
                        self.removePatternAtBeg(name, dirPath, self.pattern)

                    elif self.pattern_position == PatternLocations.patternAtEnd:
                        self.removePatternAtEnd(name, dirPath, self.pattern)

                    else:
                        self.removeDefaultPattern(name, dirPath)

                #Print all directories in current directory
                for name in dirs:
                    fold = os.path.join(dirPath, name)
                    print('Folder: '+fold)

        else:
             print('Path is not valid')

        if self.renamed_files_list:
             print('Files renamed: ')

             str_format = self.get_string_format(self.renamed_files_list.keys())
             for old_path, new_name in self.renamed_files_list.items():
                 print(str_format.format(old_path, ': ' + Fore.RED +   new_name))
             print('Successfully rename '+str(len(self.renamed_files_list))+' file/s')

        else:
            print(Fore.RED + "No file renamed")

    def get_string_format(self, list):
        str_format = '{0:<' + str(len(max(list, key=len))) + '} {1}'
        return str_format


#!/usr/bin/python3

import sys
import argparse

from .trimfilename import TrimFilename
from .utils import PatternLocations

def main():
    #initializing argument parser
    parser = argparse.ArgumentParser()

    #adding arguments
    parser.add_argument("path", help="Give the path name to rename files",
                        type=str, nargs='+')
    parser.add_argument("-p", "--patternInString", help="Give the pattern that is to "
                                                        "be removed", type=str)
    parser.add_argument("-pb", "--patternAtBeg", help="Pattern to be removed "
                                                      "is matched at beginning of the filenames", type=str)
    parser.add_argument("-pe", "--patternAtEnd", help="Pattern to be removed "
                                                      "is matched at end of the filenames(extension should be "
                                                      "included in pattern)", type=str)


    #parsing arguments
    argu = parser.parse_args()

    pattern_location = None
    pattern = None

    if argu.patternInString:
        pattern_location = PatternLocations.patternInString
        pattern = argu.patternInString
    elif argu.patternAtBeg:
        pattern_location = PatternLocations.patternAtBeg
        pattern = argu.patternAtBeg
    elif argu.patternAtEnd:
        pattern_location = PatternLocations.patternAtEnd
        pattern = argu.patternAtEnd


    trimfilename_handle = TrimFilename(pattern_location, pattern)
    #TODO: not pass argu as parameter
    for name in argu.path:
        print(name)
        trimfilename_handle.parseDir(name)

if __name__ == '__main__':
    sys.exit(main())


import os

class PatternLocations:
    patternAtBeg = 1
    patternAtEnd = 2
    patternInString = 3


def renameFile(oldname, newname, dirPath):
    ''' Renames file if name has changed
    '''

    changed_file_name = False
    old_file_path = os.path.join(dirPath, oldname)

    #Does not rename file if it begins with '.' or the whole file name gets
    #deleted after rename and also if there is no change in filename
    if newname and newname[0] != '.' and oldname != newname:
        os.rename(old_file_path, os.path.join(dirPath, newname))
        #print('Successfully renamed '+pathNname+' to'
        #       ' '+ newname)

        changed_file_name = True

    return changed_file_name


from setuptools import setup

add_keywords = dict(
    entry_points = {
        'console_scripts': ['trimfilename = trimfilename.main:main'],
        },
)

try:
    import pypandoc
    long_description = pypandoc.convert('README.md', 'rst')
except (IOError, ImportError):
    fhan = open('README.txt')
    long_description = fhan.read()
    fhan.close()

setup(

    name="trimfilename",
    version="0.5.1",
    license='GPLv3',
    description="Remove string patterns from filenames",
    url="https://github.com/tanjot/trimfilename",
    author="Tanjot Kaur",
    author_email="tanjot28@gmail.com",
    packages=['trimfilename'],
    **add_keywords
)
